@@ -41,7 +41,11 @@ def _iter_current_next(sequence):
     True
     """
     iterator = iter(sequence)
-    current_item = next(iterator)
+    try:
+        current_item = next(iterator)
+    except StopIteration:
+        return
+
     while current_item != _nonexistent:
         try:
             next_item = next(iterator)
